@@ -1,12 +1,9 @@
 import dataclasses
 from typing import (
     Any,
-    AnyStr,
     Dict,
     FrozenSet,
-    Generic,
     List,
-    Literal,
     Optional,
     Set,
     Tuple,
@@ -17,6 +14,7 @@ from typing import (
 import typing
 
 from dataclass_utils.error import Error, type_error
+from dataclass_utils.typing import Literal, get_args, get_origin
 
 Result = Optional[Error]  # returns error context
 
@@ -35,32 +33,34 @@ def check(value: Any, ty: Type) -> Result:
     if not isinstance(value, type) and dataclasses.is_dataclass(ty):
         # dataclass
         return check_dataclass(value, ty)
-    elif (to := typing.get_origin(ty)) is not None:
-        # generics
-        err = check(value, to)
-        if is_error(err):
-            return err
+    else:
+        to = get_origin(ty)
+        if to is not None:
+            # generics
+            err = check(value, to)
+            if is_error(err):
+                return err
 
-        if to is list or to is set or to is frozenset:
-            err = check_mono_container(value, ty)
-        elif to is dict:
-            err = check_dict(value, ty)
-        elif to is tuple:
-            err = check_tuple(value, ty)
-        elif to is Literal:
-            err = check_literal(value, ty)
-        elif to is Union:
-            err = check_union(value, ty)
-        return err
-    elif isinstance(ty, type):
-        # concrete type
-        if issubclass(ty, bool):
-            if not isinstance(value, ty):
+            if to is list or to is set or to is frozenset:
+                err = check_mono_container(value, ty)
+            elif to is dict:
+                err = check_dict(value, ty)  # type: ignore
+            elif to is tuple:
+                err = check_tuple(value, ty)
+            elif to is Literal:
+                err = check_literal(value, ty)
+            elif to is Union:
+                err = check_union(value, ty)
+            return err
+        elif isinstance(ty, type):
+            # concrete type
+            if issubclass(ty, bool):
+                if not isinstance(value, ty):
+                    return Error(ty=ty, value=value)
+            elif issubclass(ty, int):  # For boolean
+                return check_int(value, ty)
+            elif not isinstance(value, ty):
                 return Error(ty=ty, value=value)
-        elif issubclass(ty, int):  # For boolean
-            return check_int(value, ty)
-        elif not isinstance(value, ty):
-            return Error(ty=ty, value=value)
 
     return None
 
@@ -72,13 +72,13 @@ def check_int(value, ty: Type) -> Result:
 
 
 def check_literal(value: Any, ty: Type) -> Result:
-    if all(value != t for t in typing.get_args(ty)):
+    if all(value != t for t in get_args(ty)):
         return Error(ty=ty, value=value)
     return None
 
 
 def check_tuple(value: Any, ty: Type[Tuple]) -> Result:
-    types = typing.get_args(ty)
+    types = get_args(ty)
     if len(value) != len(types):
         return Error(ty=ty, value=value)
     for v, t in zip(value, types):
@@ -89,7 +89,7 @@ def check_tuple(value: Any, ty: Type[Tuple]) -> Result:
 
 
 def check_union(value: Any, ty) -> Result:
-    if any(not is_error(check(value, t)) for t in typing.get_args(ty)):
+    if any(not is_error(check(value, t)) for t in get_args(ty)):
         return None
     return Error(ty=ty, value=value)
 
@@ -97,7 +97,7 @@ def check_union(value: Any, ty) -> Result:
 def check_mono_container(
     value: Any, ty: Union[Type[List], Type[Set], Type[FrozenSet]]
 ) -> Result:
-    ty_item = typing.get_args(ty)[0]
+    ty_item = get_args(ty)[0]
     for v in value:
         err = check(v, ty_item)
         if is_error(err):
@@ -106,7 +106,7 @@ def check_mono_container(
 
 
 def check_dict(value: Dict, ty: Type[Dict]) -> Result:
-    args = typing.get_args(ty)
+    args = get_args(ty)
     ty_key = args[0]
     ty_item = args[1]
     for k, v in value.items():
